@@ -321,6 +321,16 @@ Survey <- R6::R6Class(
     #' @param googleanalyticsstyle The google analytics settings; `0` for None,
     #' other values for other settings.
     #' @param googleanalyticsapikey The google analytics API key.
+    #' @param new_id_fun A function to set identifiers (for XML exports, which
+    #' mirrors MySQL tables and so needs identifiers). By default, new question
+    #' objects receive this function from the group containing them; and groups
+    #' receive it from the survey containing them. This ensures that identifiers
+    #' are always unique in a survey (despite question objects not being able
+    #' to 'see' anything in the group containing them, and group objects not
+    #' being able to 'see' anything in the survey containing them; because they
+    #' 'received' this function from the parent object, and it 'bubbles down'
+    #' through groups to the questions, those functions still get and set a
+    #' private identifier property in the 'top-most' object).
     #' @return A new `Survey` object.
     initialize = function(titles,
                           descriptions = "",
@@ -377,7 +387,8 @@ Survey <- R6::R6Class(
                           nokeyboard = "N",
                           alloweditaftercompletion = "N",
                           googleanalyticsstyle = 0,
-                          googleanalyticsapikey = "") {
+                          googleanalyticsapikey = "",
+                          new_id_fun = NULL) {
 
       ###-----------------------------------------------------------------------
       ### Check whether the multilingual fields have been passed properly
@@ -419,6 +430,20 @@ Survey <- R6::R6Class(
                                 classCheck = is.numeric,
                                 className = "numeric");
 
+      ###-----------------------------------------------------------------------
+      ### Set identifier function
+      ###-----------------------------------------------------------------------
+
+      if (is.null(new_id_fun)) {
+        private$new_id <- function() {
+          private$idCounter <-
+            private$idCounter + 1;
+          return(private$idCounter);
+        }
+      } else {
+        private$new_id <- new_id_fun;
+      }
+
       ###-----------------------------------------------------------------------
       ### Set general settings
       ###-----------------------------------------------------------------------
@@ -530,11 +555,12 @@ Survey <- R6::R6Class(
       ###-----------------------------------------------------------------------
 
       thisGroup <-
-        list(id = private$new_group_id(),
+        list(id = private$new_id(),
              titles = titles,
              descriptions = descriptions,
              relevance = relevance,
-             random_group = random_group);
+             random_group = random_group,
+             new_id_fun = private$new_id);
 
       ### Add to groups in survey
       self$groups <-
@@ -568,6 +594,8 @@ Survey <- R6::R6Class(
                             lsType = NULL,
                             ...) {
 
+      groupId <- as.character(groupId);
+
       ###-----------------------------------------------------------------------
       ### Check whether this code is unique
       ###-----------------------------------------------------------------------
@@ -595,11 +623,12 @@ Survey <- R6::R6Class(
       ###-----------------------------------------------------------------------
 
       thisQuestion <-
-        Question$new(id = private$new_question_id(),
+        Question$new(id = private$new_id(),
                      code = code,
                      type = type,
                      lsType = lsType,
                      language = self$language,
+                     new_id_fun = private$new_id,
                      ...);
 
       ### Add to group
@@ -623,7 +652,7 @@ Survey <- R6::R6Class(
     #' Export the survey as a tab separated values file (see
     #' https://manual.limesurvey.org/Tab_Separated_Value_survey_structure).
     #' @param file The filename to which to save the file.
-    #' @param preventOverwriting Whether to prevent overwritting.
+    #' @param preventOverwriting Whether to prevent overwriting.
     #' @param parallel Whether to work serially or in parallel.
     #' @param encoding The encoding to use
     #' @param silent Whether to be silent or chatty.
@@ -827,7 +856,7 @@ Survey <- R6::R6Class(
       ###-----------------------------------------------------------------------
 
       ### As per
-      ### https://manual.limesurvey.org/Tab_Separated_Value_survey_structure,
+      ### https://www.limesurvey.org/manual/Tab_Separated_Value_survey_structure,
       ### identifiers should count questions and subquestions, so we map
       ### unique identifiers based on the codes onto these numeric identifiers.
 
@@ -1110,9 +1139,12 @@ Survey <- R6::R6Class(
 
   private = list(
 
-    ### Unique numeric identifiers for groups and questions in this survey
-    groupIdCounter = 0,
-    questionIdCounter = 1000,
+    ### Unique numeric identifiers (for MySQL basically)
+    idCounter = 0,
+
+    ### This will be loaded with a function to return identifiers
+    ### https://stackoverflow.com/questions/39914775/updating-method-definitions-in-r6-object-instance#51714770
+    new_id = NULL,
 
     ### Counters for exporting
     exportGroupIdMapping = c(),
@@ -1398,21 +1430,7 @@ Survey <- R6::R6Class(
                  "by clicking here:<br />{STATISTICSURL}<br /><br /><br />The ",
                  "following answers were given by the participant:",
                  "<br />{ANSWERTABLE}")
-        ),
-
-    ### Create a new group identifier and return it
-    new_group_id = function() {
-      private$groupIdCounter <-
-        private$groupIdCounter + 1;
-      return(private$groupIdCounter);
-    },
-
-    ### Create a new group identifier and return it
-    new_question_id = function() {
-      private$questionIdCounter <-
-        private$questionIdCounter + 1;
-      return(private$questionIdCounter);
-    }
+        )
 
   ) ### End of private properties and methods
 
