@@ -1,7 +1,6 @@
 #' @name limonaid-package
 #' @title limonaid-package
 #' @aliases limonaid-package limonaid
-#' @docType package
 #' @description Working With LimeSurvey Surveys and Responses
 #' @details LimeSurvey is Free/Libre Open Source Software for
 #' the development and administrations of online studies, using
@@ -9,6 +8,6 @@
 #' designs. This package supports programmatic creation of surveys
 #' that can then be imported into LimeSurvey, as well as
 #' userfriendly import of responses from LimeSurvey studies.
-#' @author Gjalt-Jorn Ygram Peters <gjalt-jorn@behaviorchange.eu>
+#' @author Gjalt-Jorn Peters <limonaid@opens.science>
 #' @keywords package
-NULL
+"_PACKAGE"
